package com.chinaitop.depot.agent.basic.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.agent.basic.model.BusinessAgentWarehouse;
import com.chinaitop.depot.agent.basic.service.agentStoreWareService;
import com.chinaitop.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value = "/agentStoreWare")
@Api(description = "代储货位信息管理")
public class AgentStoreWareController {

    @Resource
    private agentStoreWareService agentStoreWareService;

    /**
     * 货位列表
     * @return
     */
    @RequestMapping(value = "/getWareList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="货位列表", notes = "货位信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "agentDepotName", value = "粮库名称", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public PageInfo<Map<String,Object>> getWareList(Integer pageNum, Integer pageSize, String agentDepotName, String orgId){
        Map<String,Object> map = new HashMap<>();
        map.put("orgId",orgId);
        if(ParameterUtil.isnotnull(agentDepotName)){
            map.put("agentDepotName","%" + agentDepotName + "%");
        }

        PageHelper.startPage(pageNum, pageSize);
        List<Map<String,Object>> list = agentStoreWareService.getWareList(map);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<Map<String,Object>>(list);
        return pageInfo;
    }

    /**
     * 根据agent_storehouse_id(仓房id)和orgId 获取货位的列表
     */
    @RequestMapping(value = "/getAgentWarehouseList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="代储库的货位信息", notes = "代储库的货位信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query"),
            @ApiImplicitParam(name = "agentStorehouseId", value = "仓房id", paramType = "query")
    })
    public List<Map<String, Object>> getAgentWarehouseList(Integer orgId,Integer agentStorehouseId){
        Map<String,Object> map = new HashMap<>();
        map.put("orgId",orgId);
        map.put("agentStorehouseId",agentStorehouseId);
        List<Map<String, Object>> list = agentStoreWareService.getAgentStoreWare(map);
        return list;
    }

    /**
     * 查询已有货位
     */
    @RequestMapping(value="/getWarehouse", method = RequestMethod.GET)
    @ApiOperation(value="根据单位和仓房查询货位信息（货位对外接口）", notes = "根据单位和仓房查询货位信息（货位对外接口）")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "unitId", value = "单位ID", paramType = "query"),
            @ApiImplicitParam(name = "storehouseId", value = "仓房ID", paramType = "query")
    })
    public Map<String, Object> getWarehouse(Integer unitId, Integer storehouseId) {
        Map<String, Object> map = null;

        map = agentStoreWareService.getWarehouse(unitId, storehouseId);

        return map;
    }

    /**
     * 保存已有货位信息
     * @param warehouseId 已有货位
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/saveWarehouseData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存已有货位信息", notes = "保存已有货位信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "warehouseId", value = "已有货位id", paramType = "form"),
            @ApiImplicitParam(name = "storeId", value = "代储仓房id", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织结构id", paramType = "form")
    })
    public Map<String, Object> saveWarehouseData(Integer warehouseId,Integer storeId,Integer orgId) throws Exception {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        //去数据库中查询，看看是否已经添加，但是删除的数据
        Map<String,Object> getWare = new HashMap<>();
        getWare.put("warehouseId",warehouseId);
        List<Map<String,Object>> dataList = agentStoreWareService.getWare(getWare);
        if(!ParameterUtil.isequal(dataList.size(),0)){
            if(ParameterUtil.isequal(dataList.get(0).get("delFlag"),2)){//如果有已经添加但是删除的数据则回复成正常数据
                agentStoreWareService.removeAgentWare(Integer.parseInt(dataList.get(0).get("id").toString()),1);
            }else if(ParameterUtil.isequal(dataList.get(0).get("delFlag"),1)){//如果有已经添加但是没有删除的数据则提示
                modelMap.put("repeat", "success");
                return modelMap;
            }
        }else {//如果没有则新增
        	BusinessAgentWarehouse agentWarehouse = new BusinessAgentWarehouse();
            agentWarehouse.setWarehouseId(warehouseId);
            agentWarehouse.setAgentStorehouseId(storeId);
            agentWarehouse.setOrgId(orgId);
            agentWarehouse.setDelFlag(1);
            agentWarehouse.setCreateTime(ParameterUtil.string2datetime(ParameterUtil.getSysDateTime()));//修改时间
            agentWarehouse.setBgmxzTbsj(ParameterUtil.string2datetime(ParameterUtil.getSysDateTime()));
            agentWarehouse.setQccrkTbsj(ParameterUtil.string2datetime(ParameterUtil.getSysDateTime()));
            agentWarehouse.setHccrkTbsj(ParameterUtil.string2datetime(ParameterUtil.getSysDateTime()));
            agentStoreWareService.addWareHouse(agentWarehouse);
        }

        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 删除一条已有代储货位
     * @param wareId 已有货位
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/removeAgentWare", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除一条已有代储仓房", notes = "删除一条已有代储仓房")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "wareId", value = "已有货位id", paramType = "form")
    })
    public Map<String, Object> removeAgentWare(Integer wareId) throws Exception {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        agentStoreWareService.removeAgentWare(wareId,2);

        modelMap.put("status", "success");
        return modelMap;
    }
    
    
    /**
     * 除去代储货位的本库货位
     */
    @RequestMapping(value = "/getAgentWareHouseId", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="除去代储货位的本库货位", notes = "除去代储货位的本库货位")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public List<Integer> getAgentwareHouseId(Integer orgId){
        return agentStoreWareService.getAgentwareHouseId(orgId);
    }
}
