package com.chinaitop.depot.agent.basic.controller;

import com.alibaba.fastjson.JSONArray;
import com.chinaitop.depot.agent.basic.model.BusinessAgentStorehouse;
import com.chinaitop.depot.agent.basic.model.BusinessAgentWarehouse;
import com.chinaitop.depot.agent.basic.model.BusinessAgentWarehouseExample;
import com.chinaitop.depot.agent.basic.service.agentDepotService;
import com.chinaitop.depot.agent.basic.service.agentStoreWareService;
import com.chinaitop.depot.agent.basic.service.agentStorehouseService;
import com.chinaitop.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(value = "/agentStorehouse")
@Api(description = "代储仓房信息管理")
public class AgentStorehouseController {

    @Resource
    private agentDepotService agentDepotService;

    @Resource
    private agentStorehouseService agentStorehouseService;

    @Resource
    private agentStoreWareService agentStoreWareService;

    /**
     * 代储库信息
     * @return
     */
    @RequestMapping(value = "/getDepotInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="代储库信息", notes = "代储点粮库信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public List<Map<String,Object>> getDepotInfo(String orgId){
        Map<String,Object> map = new HashMap<>();
        map.put("orgId",orgId);
        List<Map<String,Object>> list = agentDepotService.getDepotLaoList(map);
        return list;
    }

    /**
     * 代储仓房信息
     * @return
     */
    @RequestMapping(value = "/getAgentStoreInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="代储仓房信息", notes = "代储点仓房信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query"),
            @ApiImplicitParam(name = "depotId", value = "代储库id", paramType = "query")
    })
    public List<Map<String,Object>> getAgentStoreInfo(String depotId, String orgId){
        Map<String,Object> map = new HashMap<>();
        map.put("orgId",orgId);
        map.put("depotId",depotId);
        List<Map<String,Object>> list = agentStorehouseService.getAgentStoreInfo(map);
        return list;
    }

    /**
     * 获取代储库下边的仓房信息，已有粮库和手加粮库都有
     * @return
     */
    @RequestMapping(value = "/getDepotToStoreList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="代储仓房信息", notes = "代储点仓房信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query"),
            @ApiImplicitParam(name = "depotId", value = "代储库id", paramType = "query")
    })
    public List<Map<String,Object>> getDepotToStoreList(String orgId, String depotId){
        Map<String,Object> map = new HashMap<>();
        map.put("orgId",orgId);
        map.put("depotId",depotId);
        List<Map<String,Object>> list = agentStorehouseService.getDepotToStoreList(map);
        return list;
    }

    /**
     * 仓房列表
     * @return
     */
    @RequestMapping(value = "/getStoreList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="仓房列表", notes = "仓房信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "agentDepotName", value = "代储库名称", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public PageInfo<Map<String,Object>> getStoreList(Integer pageNum, Integer pageSize, String agentDepotName, String orgId){
        Map<String,Object> map = new HashMap<>();
        map.put("orgId",orgId);
        if(ParameterUtil.isnotnull(agentDepotName)){
            map.put("agentDepotName","%" + agentDepotName + "%");
        }

        PageHelper.startPage(pageNum, pageSize);
        List<Map<String,Object>> list = agentStorehouseService.getStoreList(map);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<Map<String,Object>>(list);
        return pageInfo;
    }

    /**
     * 查找粮库下仓房
     * @param orgId 组织机构名称
     * @return
     */
    @RequestMapping(value="/getStorehouseList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查找粮库下仓房", notes = "查找粮库下仓房信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name="orgId", value="组织机构id", paramType="query"),
            @ApiImplicitParam(name="depotId", value="代储点Id", paramType="query")
    })
    public List<List<Map<String, Object>>> getStorehouseList(String orgId,String depotId) {
        Map<String,Object> map = new HashMap<>();
        map.put("orgId",orgId);
        if(ParameterUtil.isnotnull(depotId)){
            map.put("depotId",depotId);
        }
        //查出来的数据
        List<Map<String, Object>> list = agentStorehouseService.getStorehouseList(map);
        //准备处理，每六条数据一个list
        List<List<Map<String, Object>>> dataList = new ArrayList<List<Map<String, Object>>>();
        List<Map<String, Object>> six = new ArrayList<Map<String, Object>>();
        for (int i = 0;i<list.size();i++){
            six.add(list.get(i));
            //如果查出来的数据小于六条则直接加入总数据返回
            if(ParameterUtil.isequal(six.size(),list.size())){
                dataList.add(six);
            }
            if(ParameterUtil.isequal((i+1)%6,0)){
                dataList.add(six);
                six = new ArrayList<Map<String, Object>>();;
            }
        }
        return dataList;
    }

    /**
     * 根据agent_depot_id、orgId 获取仓房信息
     * @return
     */
    @RequestMapping(value = "/getAgentStorehouseInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="代储仓房信息", notes = "代储点仓房信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public List<Map<String, Object>> getAgentStorehouseInfo(Integer orgId,Integer agentDepotId){
        Map<String,Object> map = new HashMap<>();
        map.put("orgId",orgId);
        map.put("agentDepotId",agentDepotId);
        List<Map<String, Object>> list = agentStorehouseService.getAgentStorehouse(map);
        return list;
    }

    /**
     * 保存已有仓房信息
     * @param storehouseList 已有仓房
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/saveLaoStorehouse", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存已有仓房信息", notes = "保存已有仓房信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "storehouseList", value = "已有仓房", paramType = "form"),
            @ApiImplicitParam(name = "depotId", value = "代储点Id", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织结构id", paramType = "form")
    })
    public Map<String, Object> saveLaoStorehouse(String storehouseList,Integer depotId,Integer orgId) throws Exception {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        // JSON字符串转对象s
        List<String> depotLists = JSONArray.parseArray(storehouseList, String.class);
        for (String data : depotLists) {
            List<String> six = JSONArray.parseArray(data, String.class);
            for (String sixdata : six) {
                Map<String, String> map = ParameterUtil.stringToMap(sixdata.substring(1, sixdata.length() - 1), ":", ",");
                if (ParameterUtil.isnotnull(map.get("stateLao")) && ParameterUtil.isequal(map.get("stateLao"), "1")) {//判断库是否已经是代储仓房
                    //如果是代储仓房判断是否有改动
                    if (ParameterUtil.isequal(map.get("stateValue"), "0") || ParameterUtil.isequal(map.get("stateValue"), "false")) {
                        this.removeWareList(Integer.parseInt(map.get("id")));
                        //有改动直接删除
                        agentStorehouseService.updateStoreDeleteById(Integer.parseInt(map.get("id")),2);
                    }
                } else if (ParameterUtil.isequal(map.get("stateValue"), "true")) {
                    //去数据库中查询，看看是否已经添加，但是删除的数据
                    Map<String,Object> getStore = new HashMap<>();
                    getStore.put("storehouseId",Integer.parseInt(map.get("storehouseId")));
                    List<Map<String,Object>> dataList = agentStorehouseService.getStore(getStore);
                    if(!ParameterUtil.isequal(dataList.size(),0)){//如果有已经添加但是删除的数据则回复成正常数据
                        agentStorehouseService.updateStoreDeleteById(Integer.parseInt(dataList.get(0).get("id").toString()),1);
                    }else {//如果没有则新增
                        BusinessAgentStorehouse agentStorehouse = new BusinessAgentStorehouse();
                        agentStorehouse.setOrgId(orgId);
                        agentStorehouse.setDelFlag(1);
                        agentStorehouse.setAgentDepotId(depotId);
                        agentStorehouse.setCreateTime(ParameterUtil.string2date(ParameterUtil.getSysDateTime()));//修改时间
                        agentStorehouse.setStorehouseId(Integer.parseInt(map.get("storehouseId")));
                        agentStorehouseService.add(agentStorehouse);
                    }
                }
            }
        }

        modelMap.put("status", "success");
        return modelMap;
    }

    //根据仓房id删除仓房
    @RequestMapping(value="/removeStoreHouse", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除仓房", notes = "根据仓房id删除仓房")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "depotId", value = "代储粮库id", paramType = "form"),
            @ApiImplicitParam(name = "storehouseId", value = "仓房id", paramType = "form")
    })
    public void removeStoreHouse(Integer depotId,Integer storehouseId){
        Integer houseNum = agentDepotService.getIdHouse(depotId);
        if(houseNum == 1){
            agentDepotService.updateDeleteById(depotId,2);
        }
        agentStorehouseService.updateStoreDeleteById(storehouseId,2);
        this.removeWareList(storehouseId);
    }

    //根据仓房id删除货位
    public void removeWareList(Integer storeHouseId){
        BusinessAgentWarehouseExample example = new BusinessAgentWarehouseExample();
        BusinessAgentWarehouseExample.Criteria criteria = example.createCriteria();
        criteria.andAgentStorehouseIdEqualTo(storeHouseId);
        List<BusinessAgentWarehouse> wareList = agentStoreWareService.getWareDataList(example);
        for (BusinessAgentWarehouse wareData:wareList) {
            agentStoreWareService.removeAgentWare(wareData.getId(),2);
        }
    }
    
    
    /**
     * 获取本库的代储仓房(启用着的)
     * @return
     */
    @RequestMapping(value = "/getAgentHouseId", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取本库的代储仓房(启用着的)", notes = "获取本库的代储仓房(启用着的)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public List<Integer> getAgentHouseId(Integer orgId){
         
        return agentDepotService.getAgentHouseId(orgId);
    }
    
}
