package com.chinaitop.depot.agent.quality.controller;

import com.chinaitop.depot.agent.quality.model.BusinessAgentQualitySon;
import com.chinaitop.depot.agent.quality.model.BusinessAgentQualitySonExample;
import com.chinaitop.depot.agent.quality.service.AgentQualitySonService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author sunhongbing
 * @Date 2017/12/23
 */
@RestController
@RequestMapping(value = {"/agentQualitySon"})
@Api(value= "AgentQualitySonController", description = "质量管理中检测信息控制类")
public class AgentQualitySonController {
    @Resource
    private AgentQualitySonService agentQualitySonService;

    /**
     * 接收主表的id关联着子表的ktId
     * @param qcSonId
     * @return
     */
    @RequestMapping(value = "/findQualitycheckSonBySonId",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据质量检查id查询出关联的子表信息(包含检测信息)", notes = "根据质量检查id查询出关联的子表信息(包含检测信息)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qcSonId", value = "qcSonId", paramType = "query"),
    })
    public List<BusinessAgentQualitySon> findKtDetailsByKtId(Integer qcSonId){
        BusinessAgentQualitySonExample storageQualitycheckSonExample = new BusinessAgentQualitySonExample();
        BusinessAgentQualitySonExample.Criteria criteria = storageQualitycheckSonExample.createCriteria();
        if(qcSonId != null){
            criteria.andQualitycheckIdEqualTo(qcSonId);
        }
        return  agentQualitySonService.findQualitycheckSonExample(storageQualitycheckSonExample);
    }

    /**
     * 删除一条检测信息
     * @param sonId 数据ID
     * @return
     */
    @RequestMapping(value = "/removeSon", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="根据子表id质量检查的子表信息", notes = "根据子表id质量检查的子表信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "sonId", value = "sonId", paramType = "form"),
    })
    public Map<String, Object> removeSon(Integer sonId) {
        Map<String, Object> map = new HashMap<String, Object>();
        //删除管理的数据
        BusinessAgentQualitySonExample qualitycheckSonExample = new BusinessAgentQualitySonExample();
        BusinessAgentQualitySonExample.Criteria criteria = qualitycheckSonExample.createCriteria();
        if(sonId != null){
            criteria.andIdEqualTo(sonId);
        }
        try {
            agentQualitySonService.removeSon(qualitycheckSonExample);
            map.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            map.put("status", "error");
            map.put("msg", "删除失败！");
        }
        return map;
    }

}
